@@ -1,19 +1,15 @@
 from __future__ import annotations
 
 from textwrap import dedent
-from typing import TYPE_CHECKING
 
 import pandas as pd
 from pandas.util._decorators import doc
 
+from dtoolkit._typing import IntOrStr
 from dtoolkit.accessor.register import register_dataframe_method
 from dtoolkit.accessor.series import expand as s_expand
 
 
-if TYPE_CHECKING:
-    from dtoolkit._typing import IntOrStr
-
-
 @register_dataframe_method
 @doc(
     s_expand,
@@ -86,12 +82,12 @@ def expand(
 
     return pd.concat(
         (
-            df.get(column).expand(
+            s.expand(
                 suffix=suffix,
                 delimiter=delimiter,
                 flatten=flatten,
             )
-            for column in df
+            for _, s in df.items()
         ),
         axis=1,
     )
