@@ -1,5 +1,3 @@
-from __future__ import annotations
-
 from pandas.util._decorators import doc
 
 from dtoolkit.accessor.register import register_method_factory
@@ -9,7 +7,7 @@ from dtoolkit.geoaccessor.accessor import register_geoseries_accessor
 
 @register_method_factory
 @doc(klass=":class:`~geopandas.GeoSeries`")
-def register_geoseries_method(name: str | None = None):
+def register_geoseries_method(name: str = None):
     """
     {klass} register accessor for human.
 
@@ -101,5 +99,5 @@ def register_geoseries_method(name: str | None = None):
 
 @register_method_factory
 @doc(register_geoseries_method, klass=":class:`~geopandas.GeoDataFrame`")
-def register_geodataframe_method(name: str | None = None):
+def register_geodataframe_method(name: str = None):
     return register_geodataframe_accessor(name)
